@@ -77,8 +77,7 @@ class ApiV2Client(ApiV1Client):
             title=result.get_title(),
             signature=result.signature,
             testops_id=result.get_testops_id(),
-            execution=ResultExecution(start_time=result.execution.start_time, end_time=result.execution.end_time,
-                                      status=result.execution.status, duration=result.execution.duration,
+            execution=ResultExecution(status=result.execution.status, duration=result.execution.duration,
                                       stacktrace=result.execution.stacktrace, thread=result.execution.thread),
             fields=ResultCreateFields.from_dict(result.fields),
             attachments=[attach.hash for attach in attached],
