@@ -4,13 +4,15 @@ import shutil
 import json
 import re
 from ..models import Result, Run, Attachment
-from .. import QaseUtils, ConfigManager, Logger
+from .. import QaseUtils, Logger
+from ..models.config.connection import Format
+from ..models.config.qaseconfig import QaseConfig
 
 
 class QaseReport:
     def __init__(
             self,
-            config: ConfigManager,
+            config: QaseConfig,
             logger: Logger
     ):
         self.duration = 0
@@ -19,19 +21,19 @@ class QaseReport:
         self.config = config
         self.logger = logger
 
-        self.report_path = self.config.get("report.path", "./build/qase-report")
-        self.format = self.config.get("report.format", "json")
+        self.report_path = self.config.report.connection.path
+        self.format = self.config.report.connection.format
 
         self.start_time = None
         self.end_time = None
         self.run_id = None
-        self.environment = self.config.get("environment", None)
+        self.environment = self.config.environment
 
     def start_run(self):
         self._check_report_path()
         self.start_time = str(time.time())
 
-    def complete_run(self, exit_code=None):
+    def complete_run(self):
         self.end_time = str(time.time())
         self._compile_report()
 
@@ -66,13 +68,19 @@ class QaseReport:
                 mode = "w"
             if isinstance(attachment.content, bytes):
                 mode = "wb"
-            with open(f"{self.report_path}/attachments/{attachment.id}-{attachment.file_name}", mode) as f:
+
+            file_path = f"{self.report_path}/attachments/{attachment.id}-{attachment.file_name}"
+            with open(file_path, mode) as f:
                 f.write(attachment.content)
             # Clear content to save memory and avoid double writing
             attachment.content = None
+            attachment.file_path = file_path
+
         elif attachment.file_path:
+            file_path = f"{self.report_path}/attachments/{attachment.id}-{attachment.file_name}"
             shutil.copy2(os.path.abspath(attachment.file_path),
                          f"{self.report_path}/attachments/{attachment.id}-{attachment.file_name}")
+            attachment.file_path = file_path
 
     def _persist_attachments_in_steps(self, steps: list):
         for step in steps:
@@ -118,17 +126,17 @@ class QaseReport:
 
     # Saves a model to a file
     def _store_object(self, object, path, filename):
-        data = object.to_json()
-        if self.format == 'jsonp':
+        data = object.__str__()
+        if self.format == Format.jsonp:
             data = f"qaseJsonp({data});"
-        with open(f"{path}/{filename}.{self.format}", 'w', encoding='utf-8') as f:
+        with open(f"{path}/{filename}.{self.format.value}", 'w', encoding='utf-8') as f:
             f.write(data)
 
     def _read_object(self, source):
         data = source.read()
-        if self.format == 'json':
+        if self.format == Format.json:
             return json.loads(data)
-        elif self.format == 'jsonp':
+        elif self.format == Format.jsonp:
             jsonp_pattern = r'\w+\(\s*({[\s\S]*})\s*\);'
             match = re.search(jsonp_pattern, data)
             if match:
